MODULE sms_medusa 
   !!----------------------------------------------------------------------
   !!                     ***  sms_medusa.F90  ***  
   !! TOP :   MEDUSA  Source Minus Sink variables
   !!----------------------------------------------------------------------
   !! History :    -   !  1999-09 (M. Levy)  original code
   !!              -   !  2000-12 (O. Aumont, E. Kestenare)  add sediment 
   !!             1.0  !  2005-10 (C. Ethe) F90
   !!             1.0  !  2005-03  (A-S Kremeur) add fphylab, fzoolab, fdetlab, fdbod
   !!              -   !  2005-06  (A-S Kremeur) add sedpocb, sedpocn, sedpoca
   !!             2.0  !  2007-04  (C. Deltel, G. Madec)  Free form and modules
   !!              -   !  2008-08  (K. Popova) adaptation for MEDUSA
   !!              -   !  2008-11  (A. Yool) continuing adaptation for MEDUSA
   !!              -   !  2010-03  (A. Yool) updated for branch inclusion
   !!              -   !  2011-04  (A. Yool) updated for ROAM project
   !!----------------------------------------------------------------------

#if defined key_medusa
   !!----------------------------------------------------------------------
   !!   'key_medusa'                                         MEDUSA model
   !!----------------------------------------------------------------------
   USE par_oce
   USE par_trc

   IMPLICIT NONE
   PUBLIC

   !!----------------------------------------------------------------------
   !! NEMO/TOP 1.0 , LOCEAN-IPSL (2005) 
   !! $Id$
   !! Software governed by the CeCILL licence (modipsl/doc/NEMO_CeCILL.txt)
   !!----------------------------------------------------------------------

   INTEGER ::   numnatp_ref = -1           !! Logical units for namelist medusa
   INTEGER ::   numnatp_cfg = -1           !! Logical units for namelist medusa
   INTEGER ::   numonp      = -1           !! Logical unit for namelist medusa output

!!----------------------------------------------------------------------
!! Biological parameters
!!----------------------------------------------------------------------
!!
!! Primary production and chl related quantities
   REAL(wp) ::  xxi       !:  conversion factor from gC to mmolN 
   REAL(wp) ::  xaln      !:  Chl-a specific initial slope of P-I curve for non-diatoms 
   REAL(wp) ::  xald      !:  Chl-a specific initial slope of P-I curve for diatoms
   INTEGER  ::  jphy      !:  phytoplankton T-dependent growth switch
   REAL(wp) ::  xvpn      !:  maximum growth rate for non-diatoms
   REAL(wp) ::  xvpd      !:  maximum growth rate for diatoms
   REAL(wp) ::  xthetam   !:  maximum Chl to C ratio for non-diatoms      
   REAL(wp) ::  xthetamd  !:  maximum Chl to C ratio for diatoms    
   REAL(wp) ::  jq10      !:  specific Q10 value (jphy==2)    
!!
!! Diatom silicon parameters
   REAL(wp) ::  xsin0     !:  minimum diatom Si:N ratio
   REAL(wp) ::  xnsi0     !:  minimum diatom N:Si ratio
   REAL(wp) ::  xuif      !:  hypothetical growth ratio at infinite Si:N ratio
!!
!! Nutrient limitation
   INTEGER  ::  jliebig   !:  Liebig nutrient uptake switch
   REAL(wp) ::  xnln      !:  half-sat constant for DIN uptake by non-diatoms 
   REAL(wp) ::  xnld      !:  half-sat constant for DIN uptake by diatoms 
   REAL(wp) ::  xsld      !:  half-sat constant for Si uptake by diatoms 
   REAL(wp) ::  xfln      !:  half-sat constant for Fe uptake by non-diatoms 
   REAL(wp) ::  xfld      !:  half-sat constant for Fe uptake by diatoms  
!!
!! Grazing
   REAL(wp) ::  xgmi      !:  microzoo maximum growth rate 
   REAL(wp) ::  xgme      !:  mesozoo maximum growth rate 
   REAL(wp) ::  xkmi      !:  microzoo grazing half-sat parameter
   REAL(wp) ::  xkme      !:  mesozoo grazing half-sat parameter
   REAL(wp) ::  xphi      !:  micro/mesozoo grazing inefficiency
   REAL(wp) ::  xbetan    !:  micro/mesozoo N assimilation efficiency
   REAL(wp) ::  xbetac    !:  micro/mesozoo C assimilation efficiency
   REAL(wp) ::  xkc       !:  micro/mesozoo net C growth efficiency
   REAL(wp) ::  xpmipn    !:  grazing preference of microzoo for non-diatoms
   REAL(wp) ::  xpmid     !:  grazing preference of microzoo for diatoms
   REAL(wp) ::  xpmepn    !:  grazing preference of mesozoo for non-diatoms 
   REAL(wp) ::  xpmepd    !:  grazing preference of mesozoo for diatoms
   REAL(wp) ::  xpmezmi   !:  grazing preference of mesozoo for microzoo
   REAL(wp) ::  xpmed     !:  grazing preference of mesozoo for detritus
!!
!! Metabolic losses
   REAL(wp) ::  xmetapn   !:  non-diatom metabolic loss rate
   REAL(wp) ::  xmetapd   !:  diatom     metabolic loss rate
   REAL(wp) ::  xmetazmi  !:  microzoo   metabolic loss rate
   REAL(wp) ::  xmetazme  !:  mesozoo    metabolic loss rate
!!
!! Mortality losses
   INTEGER  ::  jmpn      !:  non-diatom mortality functional form
   REAL(wp) ::  xmpn      !:  non-diatom mortality rate
   REAL(wp) ::  xkphn     !:  non-diatom mortality half-sat constant
   INTEGER  ::  jmpd      !:  diatom     mortality functional form
   REAL(wp) ::  xmpd      !:  diatom     mortality rate
   REAL(wp) ::  xkphd     !:  diatom     mortality half-sat constant
   INTEGER  ::  jmzmi     !:  microzoo   mortality functional form
   REAL(wp) ::  xmzmi     !:  microzoo   mortality rate
   REAL(wp) ::  xkzmi     !:  microzoo   mortality half-sat constant
   INTEGER  ::  jmzme     !:  mesozoo    mortality functional form
   REAL(wp) ::  xmzme     !:  mesozoo    mortality rate
   REAL(wp) ::  xkzme     !:  mesozoo    mortality half-sat constant
!!
!! Remineralisation
   INTEGER  ::  jmd       !:  detritus T-dependent remineralisation switch
   INTEGER  ::  jsfd      !:  accelerate seafloor detritus remin. switch
   REAL(wp) ::  xmd       !:  detrital nitrogen remineralisation rate 
   REAL(wp) ::  xmdc      !:  detrital carbon remineralisation rate 
!!
!! Stochiometric ratios
   REAL(wp) ::  xthetapn  !:  non-diatom C:N ratio
   REAL(wp) ::  xthetapd  !:  diatom C:N ratio
   REAL(wp) ::  xthetazmi !:  microzoo C:N ratio
   REAL(wp) ::  xthetazme !:  mesozoo C:N ratio
   REAL(wp) ::  xthetad   !:  detritus C:N ratio
   REAL(wp) ::  xrfn      !:  phytoplankton Fe:N ratio
   REAL(wp) ::  xrsn      !:  diatom Si:N ratio (NOT USED HERE; RETAINED FOR LOBSTER)
!!
!! Iron parameters
   INTEGER  ::  jiron     !:  iron scavenging submodel switch
   REAL(wp) ::  xfe_mass  !:  iron atomic mass
   REAL(wp) ::  xfe_sol   !:  aeolian iron solubility
   REAL(wp) ::  xfe_sed   !:  sediment iron input
   REAL(wp) ::  xLgT      !:  total ligand concentration (umol/m3)
   REAL(wp) ::  xk_FeL    !:  dissociation constant for (Fe + L)
   REAL(wp) ::  xk_sc_Fe  !:  scavenging rate of "free" iron
!!
!! Gravitational sinking      
   REAL(wp) ::  vsed      !:  detritus gravitational sinking rate 
   REAL(wp) ::  xhr       !:  coefficient for Martin et al. (1987) remineralisation
!!
!! Fast-sinking detritus parameters
   INTEGER  ::  jexport   !:  fast detritus remineralisation switch
   INTEGER  ::  jfdfate   !:  fate of fast detritus at seafloor switch
   INTEGER  ::  jrratio   !:  rain ratio switch
   INTEGER  ::  jocalccd  !:  CCD switch
   REAL(wp) ::  xridg_r0  !:  Ridgwell rain ratio coefficient
   REAL(wp) ::  xfdfrac1  !:  fast-sinking fraction of diatom nat. mort. losses
   REAL(wp) ::  xfdfrac2  !:  fast-sinking fraction of mesozooplankton mort. losses
   REAL(wp) ::  xfdfrac3  !:  fast-sinking fraction of diatom silicon grazing losses
   REAL(wp) ::  xcaco3a   !:  polar (high latitude) CaCO3 fraction
   REAL(wp) ::  xcaco3b   !:  equatorial (low latitude) CaCO3 fraction
   REAL(wp) ::  xmassc    !:  organic C mass:mole ratio, C106 H175 O40 N16 P1
   REAL(wp) ::  xmassca   !:  calcium carbonate mass:mole ratio, CaCO3
   REAL(wp) ::  xmasssi   !:  biogenic silicon mass:mole ratio, (H2SiO3)n
   REAL(wp) ::  xprotca   !:  calcium carbonate protection ratio
   REAL(wp) ::  xprotsi   !:  biogenic silicon protection ratio
   REAL(wp) ::  xfastc    !:  organic C remineralisation length scale
   REAL(wp) ::  xfastca   !:  calcium carbonate dissolution length scale
   REAL(wp) ::  xfastsi   !:  biogenic silicon dissolution length scale
!!
!! Benthos parameters
   INTEGER  ::  jorgben   !:  does   organic detritus go to the benthos?
   INTEGER  ::  jinorgben !:  does inorganic detritus go to the benthos?
!!
   REAL(wp) ::  xsedn     !:  organic   nitrogen sediment remineralisation rate 
   REAL(wp) ::  xsedfe    !:  organic   iron     sediment remineralisation rate 
   REAL(wp) ::  xsedsi    !:  inorganic silicon  sediment dissolution      rate 
   REAL(wp) ::  xsedc     !:  organic   carbon   sediment remineralisation rate 
   REAL(wp) ::  xsedca    !:  inorganic carbon   sediment dissolution      rate 
   REAL(wp) ::  xburial   !:  burial rate of seafloor detritus
!!
!! River parameters
   INTEGER  ::  jriver_n  !:  riverine nitrogen?   0 = no, 1 = conc, 2 = flux
   INTEGER  ::  jriver_si !:  riverine silicon?    0 = no, 1 = conc, 2 = flux
   INTEGER  ::  jriver_c  !:  riverine carbon?     0 = no, 1 = conc, 2 = flux
   INTEGER  ::  jriver_alk!:  riverine alkalinity? 0 = no, 1 = conc, 2 = flux
   INTEGER  ::  jriver_dep!:  depth river input added to?  1 = surface, >1 possible
!!
!! Miscellaneous
   REAL(wp) ::  xsdiss    !:  diatom frustule dissolution rate
!!
!! Additional parameters
   INTEGER  ::  jpkb      !:  vertical layer for diagnostic of the vertical flux 
!!
!! UKESM diagnostics
   INTEGER  ::  jdms         !: include DMS diagnostics ? Jpalm (27-08-2014) 
   INTEGER  ::  jdms_input   !: use instant (0) or diel-average (1) inputs (AXY, 08/07/2015)
   INTEGER  ::  jdms_model   !: choice of DMS model passed to atmosphere
!!                              1 = ANDR, 2 = SIMO, 3 = ARAN, 4 = HALL
!! FOR UKESM   
   REAL(wp) ::  scl_chl      !: scaling factor for tuned Chl passed to the UM 
   INTEGER  ::  chl_out      !: select Chl field exported and scaled for UM:
                             !: 1- Surface Chl ; 2- MLD Chl
!!
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:) ::   remdmp   !: depth dependent damping coefficient of passive tracers 
!!
!! AXY (27/07/10): add in indices for depth horizons (for sinking flux
!!                 and seafloor iron inputs)
   INTEGER  ::    i0100, i0150, i0200, i0500, i1000, i1100
#if defined key_roam
!!
!! ROAM carbon, alkalinity and oxygen cycle parameters
   REAL(wp) ::  xthetaphy    !:  oxygen evolution/consumption by phytoplankton 
   REAL(wp) ::  xthetazoo    !:  oxygen consumption by zooplankton 
   REAL(wp) ::  xthetanit    !:  oxygen consumption by nitrogen remineralisation
   REAL(wp) ::  xthetarem    !:  oxygen consumption by carbon remineralisation
   REAL(wp) ::  xo2min       !:  oxygen minimum concentration
!! 
!! 3D fields of carbonate system parameters
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:,:) :: f3_pH       !: 3D pH
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:,:) :: f3_h2co3    !: 3D carbonic acid
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:,:) :: f3_hco3     !: 3D bicarbonate
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:,:) :: f3_co3      !: 3D carbonate
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:,:) :: f3_omcal    !: 3D omega calcite
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:,:) :: f3_omarg    !: 3D omega aragonite
!! 
!! 2D fields of calcium carbonate compensation depth
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: f2_ccd_cal  !: 2D calcite CCD depth
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: f2_ccd_arg  !: 2D aragonite CCD depth
!!
!! 2D fields of organic and inorganic material sedimented on the seafloor
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zb_sed_n    !: 2D organic nitrogen   (before)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zn_sed_n    !: 2D organic nitrogen   (now)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: za_sed_n    !: 2D organic nitrogen   (after)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zb_sed_fe   !: 2D organic iron       (before)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zn_sed_fe   !: 2D organic iron       (now)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: za_sed_fe   !: 2D organic iron       (after)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zb_sed_si   !: 2D inorganic silicon  (before)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zn_sed_si   !: 2D inorganic silicon  (now)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: za_sed_si   !: 2D inorganic silicon  (after)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zb_sed_c    !: 2D organic carbon     (before)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zn_sed_c    !: 2D organic carbon     (now)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: za_sed_c    !: 2D organic carbon     (after)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zb_sed_ca   !: 2D inorganic carbon   (before)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zn_sed_ca   !: 2D inorganic carbon   (now)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: za_sed_ca   !: 2D inorganic carbon   (after)
!!
!! 2D fields of temporally averaged properties for DMS calculations (AXY, 07/07/15)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zb_dms_chn  !: 2D avg CHN   (before)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zn_dms_chn  !: 2D avg CHN   (now)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: za_dms_chn  !: 2D avg CHN   (after)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zb_dms_chd  !: 2D avg CHD   (before)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zn_dms_chd  !: 2D avg CHD   (now)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: za_dms_chd  !: 2D avg CHD   (after)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zb_dms_mld  !: 2D avg MLD   (before)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zn_dms_mld  !: 2D avg MLD   (now)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: za_dms_mld  !: 2D avg MLD   (after)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zb_dms_qsr  !: 2D avg QSR   (before)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zn_dms_qsr  !: 2D avg QSR   (now)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: za_dms_qsr  !: 2D avg QSR   (after)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zb_dms_din  !: 2D avg DIN   (before)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zn_dms_din  !: 2D avg DIN   (now)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: za_dms_din  !: 2D avg DIN   (after)
!!
!! 2D fields needing to be knows at first tstp for coupling with atm - UKEMS(Jpalm,14-06-2016)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zb_co2_flx  !: 2D avg fx co2 (before)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zn_co2_flx  !: 2D avg fx co2 (now)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: za_co2_flx  !: 2D avg fx co2 (after)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zb_dms_srf  !: 2D avg sfr dms (before)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zn_dms_srf  !: 2D avg sfr dms (now)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: za_dms_srf  !: 2D avg srf dms (after)
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: zn_chl_srf  !: 2D avg srf chl (now)

#endif

!!----------------------------------------------------------------------
!! CCD parameter
!!----------------------------------------------------------------------
!!
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   ::   ocal_ccd  !: CCD depth

!!----------------------------------------------------------------------
!! Dust parameters
!!----------------------------------------------------------------------
!!
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   ::   dust      !: dust parameter 1
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   ::   zirondep  !! Fe deposition

!!----------------------------------------------------------------------
!! River parameters
!!----------------------------------------------------------------------
!!
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   ::   riv_n      !: riverine N
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   ::   riv_si     !: riverine Si
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   ::   riv_c      !: riverine C
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   ::   riv_alk    !: riverine alkalinity
   !! AXY (19/07/12): add this to permit river fluxes to be added below top box
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   ::   friver_dep !: where river fluxes added

#if defined key_roam
!!----------------------------------------------------------------------
!! Atmospheric pCO2 data (1859 to 2100 inclusive)
!!----------------------------------------------------------------------
!!
   REAL(wp), DIMENSION(242)         ::   hist_pco2 !: pCO2

# if defined key_rcp26
      !! UKMO, run AJKKH + KAAEC, RCP 2.6, pCO2 time evolution
      DATA hist_pco2 / 286.0230, 286.1730, 286.3230, 286.4480, 286.5730, &
      & 286.7230, 286.8480, 286.9480, 287.0480, 287.1730, &
      & 287.3230, 287.4730, 287.6480, 287.8480, 288.0730, &
      & 288.3480, 288.6480, 288.9730, 289.3470, 289.7470, &
      & 290.1730, 290.6470, 291.1470, 291.6220, 292.0720, &
      & 292.5220, 292.9220, 293.2470, 293.5220, 293.7470, &
      & 293.9470, 294.1220, 294.2720, 294.4220, 294.5470, &
      & 294.6470, 294.7470, 294.8470, 294.9710, 295.1710, &
      & 295.4460, 295.7470, 296.0720, 296.4210, 296.7710, &
      & 297.1460, 297.5710, 298.0210, 298.4460, 298.8460, &
      & 299.2460, 299.6450, 300.0210, 300.3710, 300.7200, &
      & 301.0450, 301.3460, 301.6710, 302.0200, 302.3450, &
      & 302.6450, 302.9700, 303.3450, 303.7200, 304.0700, &
      & 304.4700, 304.9200, 305.3440, 305.7700, 306.2450, &
      & 306.7190, 307.1700, 307.6440, 308.1190, 308.5440, &
      & 308.9440, 309.3440, 309.6940, 309.9440, 310.1190, &
      & 310.2440, 310.3190, 310.3190, 310.2440, 310.1440, &
      & 310.0690, 310.0440, 310.0690, 310.1440, 310.2690, &
      & 310.4440, 310.6940, 311.0430, 311.4440, 311.8690, &
      & 312.3680, 312.9430, 313.5430, 314.1680, 314.7900, &
      & 315.4430, 316.2150, 317.0170, 317.7370, 318.3400, &
      & 318.8680, 319.5900, 320.5890, 321.5470, 322.5770, &
      & 323.8440, 324.9260, 325.7960, 327.0810, 328.6180, &
      & 329.6830, 330.5250, 331.6880, 333.2120, 334.7870, &
      & 336.4640, 338.2990, 339.6660, 340.7310, 342.1360, &
      & 343.7200, 345.2200, 346.7350, 348.5820, 350.6740, &
      & 352.4230, 353.7910, 354.9530, 355.8210, 356.7130, &
      & 358.0630, 359.7720, 361.3970, 363.0900, 365.2560, &
      & 367.2810, 368.7980, 370.4000, 372.4550, 374.6920, &
      & 376.7440, 378.7440, 380.7580, 382.7080, 384.7300, &
      & 386.9310, 389.2150, 391.4910, 393.7710, 396.0460, &
      & 398.3240, 400.6080, 402.8950, 405.1780, 407.4550, &
      & 409.7260, 411.9930, 414.2500, 416.4410, 418.5280, &
      & 420.5250, 422.4390, 424.2720, 426.0200, 427.6750, &
      & 429.2360, 430.7050, 432.0850, 433.3580, 434.5140, &
      & 435.5740, 436.5490, 437.4420, 438.2550, 438.9810, &
      & 439.6110, 440.1430, 440.5770, 440.9450, 441.2660, &
      & 441.5410, 441.7840, 442.0050, 442.2040, 442.3780, &
      & 442.5210, 442.6200, 442.6720, 442.6810, 442.6540, &
      & 442.5830, 442.4670, 442.3270, 442.1680, 441.9960, &
      & 441.8060, 441.5930, 441.3440, 441.0540, 440.7230, &
      & 440.3510, 439.9300, 439.4650, 438.9730, 438.4630, &
      & 437.9400, 437.4020, 436.8400, 436.2640, 435.6850, &
      & 435.1030, 434.5160, 433.9170, 433.3060, 432.7010, &
      & 432.1110, 431.5380, 430.9810, 430.4320, 429.8860, &
      & 429.3370, 428.7810, 428.2220, 427.6490, 427.0660, &
      & 426.4890, 425.9270, 425.3840, 424.8610, 424.3540, &
      & 423.8540, 423.3540, 422.8530, 422.3510, 421.8410, &
      & 421.3250, 420.8190 /
# else
      !! UKMO, run AJKKH + KAAEF, RCP 8.5, pCO2 time evolution
      DATA hist_pco2 / 286.0230, 286.1730, 286.3230, 286.4480, 286.5730, &
      & 286.7230, 286.8480, 286.9480, 287.0480, 287.1730, &
      & 287.3230, 287.4730, 287.6480, 287.8480, 288.0730, &
      & 288.3480, 288.6480, 288.9730, 289.3470, 289.7470, &
      & 290.1730, 290.6470, 291.1470, 291.6220, 292.0720, &
      & 292.5220, 292.9220, 293.2470, 293.5220, 293.7470, &
      & 293.9470, 294.1220, 294.2720, 294.4220, 294.5470, &
      & 294.6470, 294.7470, 294.8470, 294.9710, 295.1710, &
      & 295.4460, 295.7470, 296.0720, 296.4210, 296.7710, &
      & 297.1460, 297.5710, 298.0210, 298.4460, 298.8460, &
      & 299.2460, 299.6450, 300.0210, 300.3710, 300.7200, &
      & 301.0450, 301.3460, 301.6710, 302.0200, 302.3450, &
      & 302.6450, 302.9700, 303.3450, 303.7200, 304.0700, &
      & 304.4700, 304.9200, 305.3440, 305.7700, 306.2450, &
      & 306.7190, 307.1700, 307.6440, 308.1190, 308.5440, &
      & 308.9440, 309.3440, 309.6940, 309.9440, 310.1190, &
      & 310.2440, 310.3190, 310.3190, 310.2440, 310.1440, &
      & 310.0690, 310.0440, 310.0690, 310.1440, 310.2690, &
      & 310.4440, 310.6940, 311.0430, 311.4440, 311.8690, &
      & 312.3680, 312.9430, 313.5430, 314.1680, 314.7900, &
      & 315.4430, 316.2150, 317.0170, 317.7370, 318.3400, &
      & 318.8680, 319.5900, 320.5890, 321.5470, 322.5770, &
      & 323.8440, 324.9260, 325.7960, 327.0810, 328.6180, &
      & 329.6830, 330.5250, 331.6880, 333.2120, 334.7870, &
      & 336.4640, 338.2990, 339.6660, 340.7310, 342.1360, &
      & 343.7200, 345.2200, 346.7350, 348.5820, 350.6740, &
      & 352.4230, 353.7910, 354.9530, 355.8210, 356.7130, &
      & 358.0630, 359.7720, 361.3970, 363.0900, 365.2560, &
      & 367.2810, 368.7980, 370.4000, 372.4550, 374.6920, &
      & 376.7440, 378.7440, 380.7580, 382.7080, 384.7300, &
      & 386.9420, 389.2540, 391.5670, 393.9370, 396.3920, &
      & 398.9320, 401.5550, 404.2550, 407.0220, 409.8530, &
      & 412.7470, 415.7050, 418.7210, 421.7880, 424.9180, &
      & 428.1200, 431.3970, 434.7470, 438.1650, 441.6410, &
      & 445.1700, 448.7530, 452.3920, 456.0950, 459.8810, &
      & 463.7680, 467.7660, 471.8750, 476.0960, 480.4210, &
      & 484.8390, 489.3470, 493.9430, 498.6400, 503.4380, &
      & 508.3410, 513.3630, 518.5160, 523.8050, 529.2290, &
      & 534.7780, 540.4450, 546.2230, 552.1120, 558.1110, &
      & 564.2110, 570.4130, 576.7390, 583.1990, 589.7980, &
      & 596.5390, 603.4110, 610.4060, 617.4940, 624.6500, &
      & 631.8800, 639.1750, 646.5360, 653.9800, 661.5230, &
      & 669.1840, 676.9570, 684.8290, 692.7790, 700.7690, &
      & 708.8050, 716.8870, 725.0020, 733.1770, 741.3900, &
      & 749.6700, 758.0480, 766.5050, 775.0350, 783.6110, &
      & 792.2200, 800.8740, 809.5680, 818.2760, 827.0090, &
      & 835.8020, 844.6550, 853.5730, 862.5690, 871.6190, &
      & 880.7020, 889.8240, 898.9590, 908.1270, 917.3080, &
      & 926.4960, 935.7040 /
# endif
#endif

!!----------------------------------------------------------------------
!! Optical parameters
!!----------------------------------------------------------------------
!!
   REAL(wp) ::   xkr0       !: water coefficient absorption in red      (NAMELIST)
   REAL(wp) ::   xkg0       !: water coefficient absorption in green    (NAMELIST)
   REAL(wp) ::   xkrp       !: pigment coefficient absorption in red    (NAMELIST)
   REAL(wp) ::   xkgp       !: pigment coefficient absorption in green  (NAMELIST)
   REAL(wp) ::   xlr        !: exposant for pigment absorption in red   (NAMELIST)
   REAL(wp) ::   xlg        !: exposant for pigment absorption in green (NAMELIST)
   REAL(wp) ::   rpig       !: chla/chla+phea ratio                     (NAMELIST)
                                                        
   INTEGER , ALLOCATABLE, SAVE, DIMENSION(:,:)   ::   neln    !: number of levels in the euphotic layer
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   ::   xze     !: euphotic layer depth
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:,:) ::   xpar    !: par (photosynthetic available radiation)

!!----------------------------------------------------------------------
!! Sediment parameters                               
!! 
!! AXY (16/01/12): these parameters were originally part of the pre-
!!                 cursor model on which MEDUSA's code was grounded;
!!                 they do not relate to the sediment/benthos submodel
!!                 added as part of the ROAM project; they have only
!!                 been retained because they are distributed through
!!                 MEDUSA and require a proper clean-up to purge
!!----------------------------------------------------------------------
!!
   REAL(wp) ::   sedlam       !: time coefficient of POC remineralization in sediments
   REAL(wp) ::   sedlostpoc   !: ???
   REAL(wp) ::   areacot      !: ???
                                                        
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: dminl       !: fraction of sinking POC released in sediments
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:,:) :: dmin3       !: fraction of sinking POC released at each level
                                                        
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: sedpocb     !: mass of POC in sediments
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: sedpocn     !: mass of POC in sediments
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: sedpoca     !: mass of POC in sediments
                                                        
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: fbodf       !: rapid sinking particles
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: fbods       !: rapid sinking particles
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: fbodn       !: rapid sinking particles
                                                        
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:,:) :: ffln        !: 
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:,:) :: fflf        !: 
   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:,:) :: ffls        !: 

   REAL(wp), ALLOCATABLE, SAVE, DIMENSION(:,:)   :: cmask       !: ???

   !!----------------------------------------------------------------------
   !! NEMO/TOP 3.3 , NEMO Consortium (2010)
   !! $Id$
   !! Software governed by the CeCILL licence     (NEMOGCM/NEMO_CeCILL.txt)
   !!----------------------------------------------------------------------
CONTAINS

   INTEGER FUNCTION sms_medusa_alloc()
      !!----------------------------------------------------------------------
      !!        *** ROUTINE sms_medusa_alloc ***
      !!----------------------------------------------------------------------
      USE lib_mpp , ONLY: ctl_warn
      INTEGER ::   ierr(8)        ! Local variables
      !!----------------------------------------------------------------------
      ierr(:) = 0
      !
#if defined key_medusa
      !* depth-dependent damping coefficient
      ALLOCATE( remdmp(jpk,jp_medusa),                           STAT=ierr(1) )
# if defined key_roam
      !* 2D and 3D fields of carbonate system parameters
      ALLOCATE( f2_ccd_cal(jpi,jpj)  , f2_ccd_arg(jpi,jpj)  ,       &
         &      f3_pH(jpi,jpj,jpk)   , f3_h2co3(jpi,jpj,jpk),       &
         &      f3_hco3(jpi,jpj,jpk) , f3_co3(jpi,jpj,jpk)  ,       &
         &      f3_omcal(jpi,jpj,jpk), f3_omarg(jpi,jpj,jpk),    STAT=ierr(2) )
      !* 2D fields of organic and inorganic material sedimented on the seafloor
      ALLOCATE( zb_sed_n(jpi,jpj)    , zn_sed_n(jpi,jpj)    ,       &
         &      za_sed_n(jpi,jpj)    ,                              &
         &      zb_sed_fe(jpi,jpj)   , zn_sed_fe(jpi,jpj)   ,       &
         &      za_sed_fe(jpi,jpj)   ,                              &
         &      zb_sed_si(jpi,jpj)   , zn_sed_si(jpi,jpj)   ,       &
         &      za_sed_si(jpi,jpj)   ,                              &
         &      zb_sed_c(jpi,jpj)    , zn_sed_c(jpi,jpj)    ,       &
         &      za_sed_c(jpi,jpj)    ,                              &
         &      zb_sed_ca(jpi,jpj)   , zn_sed_ca(jpi,jpj)   ,       &
         &      za_sed_ca(jpi,jpj)   ,                           STAT=ierr(3) )
      !* 2D fields of temporally averaged properties for DMS calculations (AXY, 07/07/15)
      ALLOCATE( zb_dms_chn(jpi,jpj)  , zn_dms_chn(jpi,jpj)  ,       &
         &      za_dms_chn(jpi,jpj)  ,                              &
         &      zb_dms_chd(jpi,jpj)  , zn_dms_chd(jpi,jpj)  ,       &		  
         &      za_dms_chd(jpi,jpj)  ,                              &
         &      zb_dms_mld(jpi,jpj)  , zn_dms_mld(jpi,jpj)  ,       &		  
         &      za_dms_mld(jpi,jpj)  ,                              &
         &      zb_dms_qsr(jpi,jpj)  , zn_dms_qsr(jpi,jpj)  ,       &		  
         &      za_dms_qsr(jpi,jpj)  ,                              &
         &      zb_dms_din(jpi,jpj)  , zn_dms_din(jpi,jpj)  ,       &		  
         &      za_dms_din(jpi,jpj)  ,                           STAT=ierr(4) )
      !* 2D fields needing to be knows at first tstp for coupling with atm -
      !UKEMSi (Jpalm,14-06-2016) 
      ALLOCATE( zb_co2_flx(jpi,jpj)  , zn_co2_flx(jpi,jpj)  ,       &
         &      za_co2_flx(jpi,jpj)  ,                              &
         &      zb_dms_srf(jpi,jpj)  , zn_dms_srf(jpi,jpj)  ,       &           
         &      za_dms_srf(jpi,jpj)  , zn_chl_srf(jpi,jpj)  ,    STAT=ierr(5) )
# endif
      !* 2D fields of miscellaneous parameters
      ALLOCATE( ocal_ccd(jpi,jpj)    , dust(jpi,jpj)        ,       &
         &      zirondep(jpi,jpj)                           ,       &
         &      riv_n(jpi,jpj)                              ,       &
         &      riv_si(jpi,jpj)      , riv_c(jpi,jpj)       ,       &
         &      riv_alk(jpi,jpj)     , friver_dep(jpk,jpk)  ,    STAT=ierr(6) )
      !* 2D and 3D fields of light parameters
      ALLOCATE( neln(jpi,jpj)        , xze(jpi,jpj)         ,       &
         &      xpar(jpi,jpj,jpk)    ,                           STAT=ierr(7) )
      !* 2D and 3D fields of sediment-associated parameters
      ALLOCATE( dminl(jpi,jpj)       , dmin3(jpi,jpj,jpk)   ,       &
         &      sedpocb(jpi,jpj)     , sedpocn(jpi,jpj)     ,       &
         &      sedpoca(jpi,jpj)     , fbodn(jpi,jpj)       ,       &
         &      fbodf(jpi,jpj)       , fbods(jpi,jpj)       ,       &
         &      ffln(jpi,jpj,jpk)    , fflf(jpi,jpj,jpk)    ,       &
         &      ffls(jpi,jpj,jpk)    , cmask(jpi,jpj)       ,    STAT=ierr(8) ) 
#endif
      !
      sms_medusa_alloc = MAXVAL( ierr )
      !
      IF( sms_medusa_alloc /= 0 )   CALL ctl_warn('sms_medusa_alloc: failed to allocate arrays')
      !
   END FUNCTION sms_medusa_alloc

#else
   !!----------------------------------------------------------------------
   !!  Empty module :                                     NO MEDUSA model 
   !!----------------------------------------------------------------------
#endif

   !!======================================================================
END MODULE sms_medusa
